KillTrig

Struct KillTrig 

pub struct KillTrig(/* private fields */);
The kill trigger is used to signal that tasks should self-terminate.

It’s possible to .await KillTrig objects to wait for all associated KillWait objects have been dropped. It is important that the task calling awaiting the KillTrig does not own an associated KillWait since this would cause a deadlock.

Implementations

Source

impl KillTrig

pub fn trigger(&self)

Signal all associated KillWait objects that their tasks should terminate.