KillSwitch

Struct KillSwitch 

pub struct KillSwitch(/* private fields */);
The KillSwitch is used both to signal termination and waiting for termination.

Implementations

Source

impl KillSwitch

pub fn new() -> Self

Create a new kill switch object.

pub fn trigger(&self)

Mark killswitch as triggered and signal all waiting tasks that they should terminate.

pub fn wait(&self) -> WaitFuture

Wait for the killswitch to be triggered.

pub fn finalize(&self) -> FinalizedFuture

Return a Future that will return Ready once there are no more waiters waiting on this killswitch to be triggered.

The KillSwitch must be triggered before calling this function, or the returned future will return an error.

pub fn reset(&self)

Reset KillSwitch.

Care should be taken when using this. Generally speaking it should only be used immediately following a KillSwitch::finalize():

use killswitch::KillSwitch;

let ks = KillSwitch::default();
assert_eq!(ks.is_triggered(), false);

// Trigger kill switch
ks.trigger();
assert_eq!(ks.is_triggered(), true);
ks.finalize().await;
ks.reset();

// KillSwitch became untriggered again
assert_eq!(ks.is_triggered(), false);

Applications should prefer to call KillSwitch::finalize_reset() rather than calling finalize() and reset().

pub async fn finalize_reset(&self) -> Result<(), ()>

Finalize and reset KillSwitch.

Returns Err(()) if the KillSwitch wasn’t in triggered state.

pub fn is_triggered(&self) -> bool

Return a boolean indicating whether kill switch has been triggered.

Returns true if kill switch has been triggered. Returns false otherwise.